from setuptools import setup

setup(
    name="freefiregen",
    version="2.0.0",
    url="https://github.com/m2-byte/freefiregen",
    author="m2_byte",
    author_email="mtwobyte@gmail.com",
    description="Python library for generating and managing Free Fire guest accounts programmatically.",
    packages=["freefiregen"],
    package_data={"freefiregen": ["*.pyd"]},  # يستخدم .pyd الموجود
    zip_safe=False,
    python_requires=">=3.8",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
    ],
)



"""
FreeFireGen — Free Fire Guest Account Generator

Author: @m2_byte
Version: 2.0.0

FreeFireGen is a lightweight Python library that provides a clean and
simple public API for programmatically creating Free Fire guest accounts.

The internal implementation is distributed as a compiled binary to
protect proprietary logic. Only the public interface exposed in this
module is considered stable and supported.
"""

from .freefiregen import create_bot_account

__all__ = ("create_bot_account",)

__version__ = "2.0.0"
__author__ = "@m2_byte"
__license__ = "Proprietary"
